==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1ProjectManagementProjectInfoBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1ProjectManagementProjectInfoBuilder extends V1alpha1ProjectManagementProjectInfoFluentImpl<V1alpha1ProjectManagementProjectInfoBuilder> implements VisitableBuilder<V1alpha1ProjectManagementProjectInfo,V1alpha1ProjectManagementProjectInfoBuilder>{

    V1alpha1ProjectManagementProjectInfoFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1ProjectManagementProjectInfoBuilder(){
            this(true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(Boolean validationEnabled){
            this(new V1alpha1ProjectManagementProjectInfo(), validationEnabled);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1ProjectManagementProjectInfo(), validationEnabled);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,V1alpha1ProjectManagementProjectInfo instance){
            this(fluent, instance, true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,V1alpha1ProjectManagementProjectInfo instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withId(instance.getId());

            fluent.withName(instance.getName());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfo instance){
            this(instance,true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfo instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withId(instance.getId());

            this.withName(instance.getName());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1ProjectManagementProjectInfo build(){
            V1alpha1ProjectManagementProjectInfo buildable = new V1alpha1ProjectManagementProjectInfo();
            buildable.setId(fluent.getId());
            buildable.setName(fluent.getName());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ProjectManagementProjectInfoBuilder that = (V1alpha1ProjectManagementProjectInfoBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ProjectManagementProjectInfoBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1ProjectManagementProjectInfoBuilder extends V1alpha1ProjectManagementProjectInfoFluentImpl<V1alpha1ProjectManagementProjectInfoBuilder> implements VisitableBuilder<V1alpha1ProjectManagementProjectInfo,V1alpha1ProjectManagementProjectInfoBuilder>{

    V1alpha1ProjectManagementProjectInfoFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1ProjectManagementProjectInfoBuilder(){
            this(true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(Boolean validationEnabled){
            this(new V1alpha1ProjectManagementProjectInfo(), validationEnabled);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1ProjectManagementProjectInfo(), validationEnabled);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,V1alpha1ProjectManagementProjectInfo instance){
            this(fluent, instance, true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfoFluent<?> fluent,V1alpha1ProjectManagementProjectInfo instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withId(instance.getId());

            fluent.withKey(instance.getKey());

            fluent.withName(instance.getName());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfo instance){
            this(instance,true);
    }
    public V1alpha1ProjectManagementProjectInfoBuilder(V1alpha1ProjectManagementProjectInfo instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withId(instance.getId());

            this.withKey(instance.getKey());

            this.withName(instance.getName());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1ProjectManagementProjectInfo build(){
            V1alpha1ProjectManagementProjectInfo buildable = new V1alpha1ProjectManagementProjectInfo();
            buildable.setId(fluent.getId());
            buildable.setKey(fluent.getKey());
            buildable.setName(fluent.getName());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ProjectManagementProjectInfoBuilder that = (V1alpha1ProjectManagementProjectInfoBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
